@@ -15,7 +15,7 @@ pytest.WITHDRAWN = None
 
 def test_deposit_and_withdraw():
     """Test case where withdrawing from a pipeline with work deposited."""
-    work = Work(pipeline=pipeline)
+    work = Work(pipeline=pipeline, user="tester", site="local")
     response: List[str] = work.deposit(return_ids=True)
     assert len(response) == 1
     # Withdrawing from the bucket should return the work
