@@ -25,13 +25,18 @@ def buckets():
 @pytest.fixture()
 def work():
     """Create a Work instance."""
-    return Work(pipeline="workflow-tests")
+    return Work(pipeline="workflow-tests", user="tester", site="local")
 
 
 @pytest.fixture()
 def work_with_command():
     """Create a Work instance."""
-    return Work(pipeline="workflow-tests", command=["echo", "{'reply': 'hello world'}"])
+    return Work(
+        pipeline="workflow-tests",
+        user="tester",
+        site="local",
+        command=["echo", "{'reply': 'hello world'}"],
+    )
 
 
 @pytest.fixture()
@@ -39,6 +44,8 @@ def work_with_command_and_tuple_reply():
     """Create a Work instance."""
     return Work(
         pipeline="workflow-tests",
+        user="tester",
+        site="local",
         command=["echo", "({'reply': 'hello world'}, ['hi'], ['there'])"],
     )
 
@@ -46,7 +53,12 @@ def work_with_command_and_tuple_reply():
 @pytest.fixture()
 def work_with_stdout_cmd():
     """Create a Work instance."""
-    return Work(pipeline="workflow-tests", command=["echo", "hello world"])
+    return Work(
+        pipeline="workflow-tests",
+        user="tester",
+        site="local",
+        command=["echo", "hello world"],
+    )
 
 
 def invoke_run(func_name: str, lifetime: int = 1):
@@ -58,7 +70,7 @@ def invoke_run(func_name: str, lifetime: int = 1):
             "workflow-tests",
             "chime_frb_api.tests.test_workflow." + func_name,
             "--lifetime=%i" % lifetime,
-            "--base-urls=http://localhost:8000",
+            "--base-url=http://localhost:8000",
             "--site=local",
             "--sleep-time=1",
             "--log-level=DEBUG",
@@ -74,7 +86,7 @@ def invoke_dynamic_run(lifetime: int = 1):
             "run",
             "workflow-tests",
             "--lifetime=%i" % lifetime,
-            "--base-urls=http://localhost:8000",
+            "--base-url=http://localhost:8000",
             "--site=local",
             "--sleep-time=1",
             "--log-level=DEBUG",
@@ -185,7 +197,7 @@ def test_bad_base_url():
             "workflow-tests",
             "chime_frb_api.tests.test_workflow.sleep_func",
             "--lifetime=1",
-            "--base-urls=http://localhost:9000",
+            "--base-url=http://localhost:9000",
             "--site=local",
             "--sleep-time=1",
             "--log-level=DEBUG",
